﻿using System;
using System.Collections.Generic;
using System.Reflection;

namespace HeuristicLab.PluginInfrastructure {
  /// <summary>
  /// Interface for an assembly loading mechanism
  /// </summary>
  public interface IAssemblyLoader {
    /// <summary>
    /// Returns all loaded assemblies.
    /// </summary>
    IEnumerable<Assembly> Assemblies { get; }

    /// <summary>
    /// Returns all types.
    /// </summary>
    IEnumerable<Type> Types { get; }

    /// <summary>
    /// Loads all assemblies (.dll/.exe) in the specified path.
    /// </summary>
    /// <param name="basePath">Path to root directory of all assemblies to load.</param>
    /// <returns>An IEnumerable of assemblies.</returns>
    IEnumerable<Assembly> LoadAssemblies(string basePath);

    /// <summary>
    /// Loads all specified assemblies.
    /// </summary>
    /// <param name="assemblyInfos">Infos for all assemblies to load.</param>
    /// <returns>An IEnumerable of assemblies.</returns>
    IEnumerable<Assembly> LoadAssemblies(IEnumerable<AssemblyInfo> assemblyInfos);
  }
}
